package com.takensoft.ai_lms.lms.book.service.Impl;

import com.takensoft.ai_lms.common.idgen.service.IdgenService;
import com.takensoft.ai_lms.lms.book.dao.BookDAO;
import com.takensoft.ai_lms.lms.book.service.BookService;
import com.takensoft.ai_lms.lms.book.vo.BookVO;
import lombok.RequiredArgsConstructor;
import org.egovframe.rte.fdl.cmmn.EgovAbstractServiceImpl;
import org.springframework.stereotype.Service;
import java.util.List;

/**
 * @author  : 구자현
 * @since   : 2024.07.25
 *
 * 교재 관련 ServiceImpl 클래스
 */
@Service
@RequiredArgsConstructor
public class BookServiceImpl extends EgovAbstractServiceImpl implements BookService {

    private final BookDAO bookDAO;

    private final IdgenService bookIdgn;

    /**
     * @author  : 구자현
     * @since   : 2024.07.25
     *
     * 전체 교재 목록 출력
     */
    @Override
    public List<BookVO> getAllBooks() {
        return bookDAO.getAllBooks();
    }

    /**
     * @author  : 구자현
     * @since   : 2024.07.25
     *
     * 책의 상세 정보
     */
    @Override
    public BookVO getBookById(String book_id) {
        return bookDAO.getBookById(book_id);
    }

    /**
     * @author  : 구자현
     * @since   : 2024.07.25
     *
     * 교재 등록
     */
    @Override
    public void insertBook(BookVO book) {
        String book_id = bookIdgn.getNextStringId();
        book.setBook_id(book_id);
        bookDAO.insertBook(book);
    }

    /**
     * @author  : 구자현
     * @since   : 2024.07.25
     *
     * 교재 제목 수정
     */
    @Override
    public void updateBook(BookVO book) {
        bookDAO.updateBook(book);
    }

    /**
     * @author  : 구자현
     * @since   : 2024.07.25
     *
     * 교재 삭제
     */
    @Override
    public void deleteBook(String book_id) {
        bookDAO.deleteBook(book_id);
    }
}